## Assessment of morphological and growth-related traits

To determine the relative growth rate (RGR) of the 23 barley inbreds, aboveground biomass data were collected in the field experiment in Düsseldorf at six different time points during the vegetative period: at 62, 69, 76, 83, 97, and 125 DAS. Plants of one row (initially 33 kernels were sown) per plot were harvested for the 23 genotypes with three replicate plots. Wild animals visited the trails, and therefore the number of damaged plants for each row was recorded.

The dry weight per row per plot was used to estimate the dry mass per plant (DMP), which was needed for the assessment of growth curve parameters, using the following equation:

**(1)**
$$DMP=\frac{DM}{(TNP-NDP)+0.8\times NDP}$$

where TNP was the total number of plants, NDP the number of damaged plants, 0.8 was the completeness of the damaged plants based on the observation during the harvest. DMP calculated as described above, was corrected separately for each time point for replicate and block effects. The corrected values were then used for further analyses.

In the climate chamber experiment, the total aboveground DMP was measured by weighing at eight different time points (26, 36, 46, 57, 74, 102, 113, and 142 DAS) except for the two inbreds IG31424 and HOR1842, for which only the initial and the final DMP were determined at 26 and 142 DAS. Three replicates per genotype were collected for each time point.

To assess the relationship between DMP and time, logistic (Verhulst, 1838), power-low (Paine et al., 2012), and quadratic regression (Lithourgidis and Dordas, 2010) models were fitted. The quadratic regression model was used:

**(2)**
$$y_r=a+bt-ct^2$$

where *a* represents the initial biomass, *b* and *c* the growth rate parameters. This model had a high coefficient of determination (⁠$R^2$⁠) and the highest heritability across all 23 barley inbreds. Thus, the quadratic regression was used for estimation of RGR. $RGR_a$, $RGR_b$, $RGR_c$ represent the parameters in quadratic regression *a*, *b*, and *c*, respectively.

Morphological parameters were collected in multi-year and multi-environment field experiments that took place in the years 2017–2021 at Düsseldorf, Cologne, Mechernich, and Quedlinburg (Shrestha et al., 2022; Wu et al., 2022). Not all locations were used in all years to assess all parameters. Flag leaf length (FL, cm) and width (FW, cm), plant height (PH, cm), flowering time (FT), awn length (AL, cm), spike length (EL, cm), and spikelet number in one row of the spike (SR), seed length (SL, mm), seed width (SW, mm), seed area (SA, mm2), and thousand grain weight (TGW, g), grain weight (GW, kg per 10 m2), and net straw weight (NSW, kg per 10 m2) were measured as morphological parameters. FL, FW, AL, EL were measured by ruler, SL, SW, and SA were measured by MARViN seed analyser (MARViNTECH GmbH, Germany), and TGW was measured by MARViN and a balance.

The same set of morphological parameters were also measured in the climate chamber experiment. FL and FW were collected at 74 and 102 DAS with three replicates, and spike-related traits (AL, EL, SR, SL, SW SA, and TGW) were collected at 142 DAS with three replicates. Additionally, the total stem (without spike) weight per plant (SWP, g), total spike weight per plant (SKWP, g), total stem weight of main stem (TSWM, g), and spike weight of main stem (SKWM, g) were also collected in the climate chamber experiment. Harvest index (HI) was calculated using the following equation:

**(3)**
$$HI=\frac{SKWP}{DMP}$$

In addition, harvest index of main stem (MSHI) was calculated using the following equation:

**(4)**
$$MSHI=\frac{SKWP}{TSWM}$$